<?xml version="1.0"?>
<!-- $Revision: 757 $ -->
<!-- $Date: 2010-07-22 14:30:09 +0900 (Thu, 22 Jul 2010) $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" encoding="UTF-8" indent="yes" />
  <!--limitation parameter-->
  <xsl:param name="selectedAgent"/>
  <xsl:param name="priorityDestination"/>

  <xsl:template match="/">
    <JobTemplates>
      <GroupList>
        <xsl:apply-templates select="DBRoot/TemplateDB/SCNGRP/rec"/>
      </GroupList>
      <ExtendedFieldDefinitionList>
        <xsl:apply-templates select="DBRoot/TemplateDB/MASTERDATA"/>
      </ExtendedFieldDefinitionList>
    </JobTemplates>
  </xsl:template>

  <xsl:template match="DBRoot/TemplateDB/SCNGRP/rec">

    <!--valueUIDISPID=Meta ScanテンプレートグループID[10000～10100]-->
    <xsl:variable name="valueUIDISPID">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="UIDISPID" />
      </xsl:call-template>
    </xsl:variable>

    <!-- Meta Scan Templateに対してのみ処理を適用-->
    <xsl:if test="$valueUIDISPID&gt;=10000">

      <!--valueGROUPID=通常テンプレートも含んだグループID-->
      <xsl:variable name="valueGROUPID">
        <xsl:call-template name="trim">
          <xsl:with-param name="s" select="GROUPID" />
        </xsl:call-template>
      </xsl:variable>

      <!--valueXMLFILEFORMAT=XML Format file名-->
      <xsl:variable name="valueXMLFILEFORMAT">
        <xsl:call-template name="trim">
          <xsl:with-param name="s" select="XMLFILEFORMAT" />
        </xsl:call-template>
      </xsl:variable>

      <Group>
        <xsl:attribute name="gid">
          <xsl:value-of select="format-number($valueUIDISPID - 10000, '000')"/>
        </xsl:attribute>
        <MetaData>
          <groupName>
            <xsl:call-template name="trim">
              <xsl:with-param name="s" select="NAME" />
            </xsl:call-template>
          </groupName>
          <userName>
            <xsl:call-template name="trim">
              <xsl:with-param name="s" select="OWNER" />
            </xsl:call-template>
          </userName>
          <isPasswordProtected>
            <xsl:variable name="password">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="PAS" />
              </xsl:call-template>
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="$password=''">false</xsl:when>
              <xsl:otherwise>true</xsl:otherwise>
            </xsl:choose>
          </isPasswordProtected>
          <ownerName>
            <xsl:call-template name="trim">
              <xsl:with-param name="s" select="OWNER" />
            </xsl:call-template>
          </ownerName>
          <notificationEmail>
            <xsl:call-template name="trim">
              <xsl:with-param name="s" select="NOTIFTO" />
            </xsl:call-template>
          </notificationEmail>
          <TemplateCount>
            <!--変換されないテンプレートを考慮してテンプレートの数をカウント-->
            <xsl:call-template name="TemplateCount">
              <xsl:with-param name="valueUIDISPID" select="$valueUIDISPID"/>
            </xsl:call-template>
          </TemplateCount>
        </MetaData>
        <password>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="PAS" />
          </xsl:call-template>
        </password>
        <TemplateList>
          <xsl:for-each select="../../TemplateRec/rec2">
            <xsl:variable name="valueGRPNUM">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="TEMPLATE/GRPNUM"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="valueEMAILAGTID">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="TEMPLATE/EMAILAGTID"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="valueFILEAGTID">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="TEMPLATE/FILEAGTID"/>
              </xsl:call-template>
            </xsl:variable>

            <!--複数Agentが設定されているか？(true or false)-->
            <xsl:variable name="valueMULTIAGENT">
              <xsl:call-template name="MULTIAGENT"/>
            </xsl:variable>

            <!--複数宛先が設定されているか？(true or false)-->
            <xsl:variable name="valueMULTIDESTINATION">
              <xsl:call-template name="MULTIDESTINATION"/>
            </xsl:variable>


            <!--変換対象のテンプレートか?(true or false)-->
            <xsl:variable name="valueeBXTEMPLATE">
              <xsl:call-template name="eBXTEMPLATE">
                <xsl:with-param name="GRPNUM" select="$valueGRPNUM"/>
                <xsl:with-param name="UIDISPID" select="$valueUIDISPID"/>
              </xsl:call-template>
            </xsl:variable>

            <xsl:if test="$valueeBXTEMPLATE = 'true'">
              <!--処理するエージェントを変数に格納-->
              <xsl:variable name="Agent">
                <xsl:choose>
                  <!--複数エージェントが設定されている場合-->
                  <xsl:when test="$valueMULTIAGENT = 'true'">
                    <xsl:if test="$selectedAgent='EMAIL'">EMAIL</xsl:if>
                    <xsl:if test="$selectedAgent='FILE'">FILE</xsl:if>
                    <xsl:if test="$selectedAgent='FILE and EMAIL'">FILE;EMAIL</xsl:if>
                  </xsl:when>
                  <!--片方のエージェントのみ指定されていた時-->
                  <xsl:otherwise>
                    <xsl:choose>
                      <xsl:when test="$valueEMAILAGTID!=''">EMAIL</xsl:when>
                      <xsl:otherwise>FILE</xsl:otherwise>
                    </xsl:choose>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:variable>

              <Template>
                <xsl:variable name="valueTEMPLATEID">
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="TEMPLATE/UIDISPID"/>
                  </xsl:call-template>
                </xsl:variable>
                <xsl:attribute name="tid">
                  <xsl:value-of select="format-number(($valueTEMPLATEID - 600000) mod 60,'000')" />
                </xsl:attribute>
                <xsl:attribute name="gid">
                  <!--TEMPLATE/GRPNUMでよいか？<SCNGRP><rec><GROUPID>か？-->
                  <xsl:value-of select="format-number($valueGRPNUM - 10000,'000')" />
                </xsl:attribute>
                <MetaData>
                  <caption1>
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="TEMPLATE/NAME1" />
                    </xsl:call-template>
                  </caption1>
                  <caption2>
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="TEMPLATE/NAME2" />
                    </xsl:call-template>
                  </caption2>
                  <userName>
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="TEMPLATE/OWNER" />
                    </xsl:call-template>
                  </userName>
                  <autoStart>
                    <xsl:variable name="valuePICTID">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="TEMPLATE/PICTID" />
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:choose>
                      <xsl:when test="$valuePICTID=''">false</xsl:when>
                      <xsl:otherwise>true</xsl:otherwise>
                    </xsl:choose>
                  </autoStart>
                  <isPasswordProtected>
                    <xsl:variable name="valuePAS">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="TEMPLATE/PAS" />
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:choose>
                      <xsl:when test="$valuePAS=''">false</xsl:when>
                      <xsl:otherwise>true</xsl:otherwise>
                    </xsl:choose>
                  </isPasswordProtected>
                  <ownerName>
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="TEMPLATE/OWNER" />
                    </xsl:call-template>
                  </ownerName>
                  <type>MetaScan</type>
                  <NotificationSettings>
                    <email>
                      <xsl:variable name="onJobComp">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="TEMPLATE/NOTIFCMP" />
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:variable name="onError">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="TEMPLATE/NOTIFERR" />
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:variable name="valueNOTIFTO">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s"  select="TEMPLATE/NOTIFTO"/>
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:attribute name="Enabled">
                        <xsl:choose>
                          <xsl:when test="$valueNOTIFTO=''">false</xsl:when>
                          <xsl:otherwise>true</xsl:otherwise>
                        </xsl:choose>
                      </xsl:attribute>
                      <xsl:if test="($onJobComp!='' or $onError!='')" >
                        <xsl:if test="($valueNOTIFTO!='')" >
                      <xsl:value-of select="$valueNOTIFTO"/>
                        </xsl:if>
                        <xsl:if test="($valueNOTIFTO='')" >
                          <xsl:for-each select="/DBRoot/TemplateDB/SCNGRP/rec">
                            <xsl:variable name="valueGroupNum">
                          <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="UIDISPID"/>
                              </xsl:call-template>
                            </xsl:variable>  
                            <xsl:if test="$valueGroupNum=$valueGRPNUM">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="NOTIFTO"/>
                          </xsl:call-template>
                        </xsl:if>
                          </xsl:for-each>
                        </xsl:if>
                      </xsl:if>
                    </email>
                    <onError>
                      <xsl:variable name="valueNOTIFERR">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="TEMPLATE/NOTIFERR" />
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:if test="$valueNOTIFERR=''">false</xsl:if>
                      <xsl:if test="$valueNOTIFERR!=''">true</xsl:if>
                    </onError>
                    <onJobCompletion>
                      <xsl:variable name="valueNOTIFCMP">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="TEMPLATE/NOTIFCMP" />
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:if test="$valueNOTIFCMP=''">false</xsl:if>
                      <xsl:if test="$valueNOTIFCMP!=''">true</xsl:if>
                    </onJobCompletion>
                  </NotificationSettings>
                  <SourceAgent>Scan</SourceAgent>
                  <Destinations>
                    <xsl:choose>
                      <xsl:when test="$Agent='EMAIL'">
                        <EmailSend Enabled="true"/>
                        <FileStore Enabled="false"/>
                      </xsl:when>
                      <xsl:when test="($Agent!='EMAIL' and $Agent!='FILE')">
                        <EmailSend Enabled="true"/>
                        <FileStore Enabled="true"/>
                      </xsl:when>
                      <xsl:otherwise>
                        <EmailSend Enabled="false"/>
                        <FileStore Enabled="true"/>
                      </xsl:otherwise>
                    </xsl:choose>
                    <EfilingStore Enabled="false"/>
                    <USBStore Enabled="false"/>
                    <Print Enabled="false"/>
                  </Destinations>
                </MetaData>
                <Params>
                  <Queues>
                    <Scan>
                      <WorkflowExecutionParameter>
                        <WorkflowPolicy/>
                        <OwnerInformation/>
                        <ColorParameter>
                          <xsl:attribute name="Enabled">true</xsl:attribute>
                          <ColorMode>
                            <xsl:variable name="valueCOLORMODE">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/COLORMODE"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:choose>
                              <xsl:when test="$valueCOLORMODE=10">AutoColor</xsl:when>
                              <xsl:when test="$valueCOLORMODE=9">AutoColor</xsl:when>
                              <xsl:when test="$valueCOLORMODE=5">FullColor</xsl:when>
                              <xsl:when test="$valueCOLORMODE=1">GrayScale8bit</xsl:when>
                              <xsl:when test="$valueCOLORMODE=''">Monochrome</xsl:when>
                              <xsl:otherwise>Monochrome</xsl:otherwise>
                            </xsl:choose>
                          </ColorMode>
                        </ColorParameter>
                        <ImageAdjustmentParameter>
                          <xsl:attribute name="Enabled">true</xsl:attribute>
                          <ImageMode>
                            <xsl:variable name="valueSCNMODE">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SCNMODE"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:choose>
                              <!--
                              <xsl:when test="$valueSCNMODE=6">PrintedImage</xsl:when>
                              <xsl:when test="$valueSCNMODE=6">Text</xsl:when>
							  -->
							  <xsl:when test="$valueSCNMODE=6">PrintedImage</xsl:when>
                              <xsl:when test="$valueSCNMODE=3">Photo</xsl:when>
                              <xsl:when test="$valueSCNMODE=2">Text</xsl:when>
                              <xsl:when test="$valueSCNMODE=1">TextPhoto</xsl:when>
                              <xsl:otherwise>Text</xsl:otherwise>
                            </xsl:choose>
                          </ImageMode>
                          <ImageQuality>
                            <xsl:variable name="valueIMAGECOMPRESSION">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="TEMPLATE/IMAGECOMPRESSION"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:choose>
                              <xsl:when test="$valueIMAGECOMPRESSION=1">High</xsl:when>
                              <xsl:when test="$valueIMAGECOMPRESSION=2">Middle</xsl:when>
                              <xsl:when test="$valueIMAGECOMPRESSION=3">Low</xsl:when>
                              <xsl:otherwise>Middle</xsl:otherwise>
                            </xsl:choose>
                          </ImageQuality>
                          <ImageRotate>
                            <xsl:variable name="valueSCNDIR">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="TEMPLATE/SCNDIR"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:choose>
                              <xsl:when test="$valueSCNDIR=''">0</xsl:when>
                              <xsl:when test="$valueSCNDIR=1">90</xsl:when>
                              <xsl:when test="$valueSCNDIR=2">180</xsl:when>
                              <xsl:when test="$valueSCNDIR=3">270</xsl:when>
                              <xsl:otherwise>0</xsl:otherwise>
                            </xsl:choose>
                          </ImageRotate>
                          <Exposure>
                            <xsl:variable name="valueDenslevel">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/DENSLEVEL"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <ExposureLevel>
                              <xsl:choose>
                                <xsl:when test="$valueDenslevel=''">0</xsl:when>
                                <xsl:otherwise>
                                  <xsl:value-of select="$valueDenslevel"/>
                                </xsl:otherwise>
                              </xsl:choose>
                            </ExposureLevel>
                            <xsl:variable name="valueScndens">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SCNDENS"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <ExposureMode>
                              <xsl:choose>
                                <xsl:when test="$valueScndens!=''">Manual</xsl:when>
                                <xsl:otherwise>Auto</xsl:otherwise>
                              </xsl:choose>
                            </ExposureMode>
                          </Exposure>
                          <BackgroundAdjustment>
                            <xsl:variable name="valueBACKGROUND">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/BACKGROUND"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:if test="$valueBACKGROUND=''">0</xsl:if>
                            <xsl:if test="$valueBACKGROUND!=''">
                              <xsl:value-of select="$valueBACKGROUND"/>
                            </xsl:if>
                          </BackgroundAdjustment>
                          <Sharpness>
                            <xsl:variable name="valueSHARPNESS">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SHARPNESS"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:if test="$valueSHARPNESS=''">0</xsl:if>
                            <xsl:if test="$valueSHARPNESS!=''">
                              <xsl:value-of select="$valueSHARPNESS"/>
                            </xsl:if>
                          </Sharpness>
                          <RGBAdjustment>
                            <Red>
                              <xsl:variable name="valueRGBR">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/RGBR"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:if test="$valueRGBR=''">0</xsl:if>
                              <xsl:if test="$valueRGBR!=''">
                                <xsl:value-of select="$valueRGBR"/>
                              </xsl:if>
                            </Red>
                            <Green>
                              <xsl:variable name="valueRGBG">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/RGBG"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:if test="$valueRGBG=''">0</xsl:if>
                              <xsl:if test="$valueRGBG!=''">
                                <xsl:value-of select="$valueRGBG"/>
                              </xsl:if>
                            </Green>
                            <Blue>
                              <xsl:variable name="valueRGBB">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/RGBB"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:if test="$valueRGBB=''">0</xsl:if>
                              <xsl:if test="$valueRGBB!=''">
                                <xsl:value-of select="$valueRGBB"/>
                              </xsl:if>
                            </Blue>
                          </RGBAdjustment>
                          <Contrast>
                            <xsl:variable name="valueSCANCONTRAST">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SCANCONTRAST"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:if test="$valueSCANCONTRAST=''">0</xsl:if>
                            <xsl:if test="$valueSCANCONTRAST!=''">
                              <xsl:value-of select="$valueSCANCONTRAST"/>
                            </xsl:if>

                          </Contrast>
                          <Saturation>
                            <xsl:variable name="valueSCANSAT">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SCANSATY"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:choose>
                              <xsl:when test="$valueSCANSAT=''">0</xsl:when>
                              <xsl:otherwise>
                                <xsl:value-of select="$valueSCANSAT"/>
                              </xsl:otherwise>
                            </xsl:choose>
                          </Saturation>
                        </ImageAdjustmentParameter>
                        <Scan>
                          <xsl:attribute name="Enabled">true</xsl:attribute>
                          <ScanParameter>
                            <xsl:variable name="valueSCNPSIZE">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s"  select="TEMPLATE/SCNPSIZE"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <xsl:variable name="valueMixOrg">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="TEMPLATE/MIXORG"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <OriginalSizeInformation>
                              <OriginalSize>
                                <xsl:choose>
                                  <xsl:when test="$valueSCNPSIZE=900">Undefined</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=31">A3-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=40">A4</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=211">LEDGER-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=200">LETTER</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=41">A4-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=51">A5-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=201">LETTER-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=221">LEGAL-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=141">B4-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=150">B5</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=231">STATEMENT-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=241">COMPUTER-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=151">B5-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=251">FOLIO-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=261">13inchLEGAL-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=271">8.5SQ</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=401">8K-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=410">16K</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=411">16K-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=500">A6</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=501">A6-R</xsl:when>
                                  <xsl:when test="$valueSCNPSIZE=61">A6-R</xsl:when>
                                  <xsl:otherwise>Undefined</xsl:otherwise>
                                </xsl:choose>
                              </OriginalSize>
                            </OriginalSizeInformation>
                            <AutoOriginalDetectionMode>
                              <xsl:choose>
                                <xsl:when test="$valueSCNPSIZE=900">true</xsl:when>
                                <xsl:otherwise>false</xsl:otherwise>
                              </xsl:choose>
                            </AutoOriginalDetectionMode>
                            <MixedOriginalSizes>
                              <!--1の時にtrueとなる設定でよいのか？-->
                              <!--Original Size=Autoの時に１-->
                              <!--Original Size=Mixed Original Sizeの時は空文字-->
                              <xsl:choose>
                                <xsl:when test="$valueMixOrg !=''">false</xsl:when>
                                <xsl:otherwise>true</xsl:otherwise>
                              </xsl:choose>
                            </MixedOriginalSizes>
                            <DuplexMode>
                              <xsl:variable name="valueSCNMETHOD">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/SCNMETHOD"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:choose>
                                <xsl:when test="$valueSCNMETHOD=1">Simplex</xsl:when>
                                <xsl:when test="$valueSCNMETHOD=2">Book</xsl:when>
                                <xsl:when test="$valueSCNMETHOD=3">Tablet</xsl:when>
                                <xsl:otherwise>Simplex</xsl:otherwise>
                              </xsl:choose>
                            </DuplexMode>
                            <Resolution>
                              <xsl:variable name="valueSCNRESO">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/SCNRESO"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:choose>
                                <xsl:when test="$valueSCNRESO=12">100</xsl:when>
                                <xsl:when test="$valueSCNRESO=10">150</xsl:when>
                                <xsl:when test="$valueSCNRESO=11">200</xsl:when>
                                <xsl:when test="$valueSCNRESO=1">300</xsl:when>
                                <xsl:when test="$valueSCNRESO=2">400</xsl:when>
                                <xsl:when test="$valueSCNRESO=3">600</xsl:when>
                                <xsl:otherwise>100</xsl:otherwise>
                              </xsl:choose>
                            </Resolution>
                            <OutSideErase>
                              <xsl:variable name="valueSCANOUTSIDEERA">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/SCANOUTSIDEERA"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:variable name="valueSCNOUTSIDEERATHR">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/SCANOUTSIDEERATHR"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <Enabled>
                                <xsl:choose>
                                  <xsl:when test="$valueSCANOUTSIDEERA!=''">true</xsl:when>
                                  <xsl:otherwise>false</xsl:otherwise>
                                </xsl:choose>
                              </Enabled>
                              <DetectExposureLevel>
                                <xsl:if test="$valueSCNOUTSIDEERATHR=''">0</xsl:if>
                                <xsl:if test="$valueSCNOUTSIDEERATHR!=''">
                                  <xsl:value-of select="$valueSCNOUTSIDEERATHR"/>
                                </xsl:if>
                              </DetectExposureLevel>
                            </OutSideErase>
                            <OmitBlankPage>
                              <xsl:variable name="valueSCANOMITBLPG">
                                <xsl:call-template name="trim">
                                  <xsl:with-param name="s"  select="TEMPLATE/SCANOMITBLPG"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <Enabled>
                                <xsl:choose>
                                  <xsl:when test="$valueSCANOMITBLPG!=''">true</xsl:when>
                                  <xsl:otherwise>false</xsl:otherwise>
                                </xsl:choose>
                              </Enabled>
                              <DetectBlankLevel>0</DetectBlankLevel>
                            </OmitBlankPage>
                          </ScanParameter>
                          <Output>
                            <xsl:variable name="valuePREVIEW">
                              <xsl:call-template name="trim">
                                <xsl:with-param name="s" select="TEMPLATE/SCANPREVIEW"/>
                              </xsl:call-template>
                            </xsl:variable>
                            <Preview>
                              <xsl:attribute name="Enabled">
                                <xsl:choose>
                                  <xsl:when test="$valuePREVIEW != ''">true</xsl:when>
                                  <xsl:otherwise>false</xsl:otherwise>
                                </xsl:choose>
                              </xsl:attribute>
                            </Preview>
                            <!--$Agent：処理すべきエージェント(FILEまたはEMAIL-->
                            <xsl:if test="$Agent='EMAIL'">
                              <xsl:apply-templates select="MAILAGT"/>
                            </xsl:if>
                            <!--
                            <xsl:if test="$Agent='FILE'">
                            -->
                            <!--
                            <xsl:if test="$Agent!='EMAIL'">
                            -->
                            <xsl:if test="$Agent='FILE'">
                              <xsl:apply-templates select="FILEAGT"/>
                            </xsl:if>
                            <xsl:if test="$Agent='FILE;EMAIL'">
                                  <xsl:apply-templates select="FILEAGT"/>
                                  <xsl:apply-templates select="MAILAGT"/>
                            </xsl:if>
                          </Output>
                        </Scan>
                      </WorkflowExecutionParameter>
                    </Scan>
                  </Queues>
                  <xsl:if test="$Agent='EMAIL' or $Agent='FILE and EMAIL'">
                    <eMailFileName>
                      <xsl:variable name="valueEmailTimeStamp">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="MAILAGT/TIMESTAMP"/>
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:variable name="valueEmailAddFileName">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="MAILAGT/ADDFILENAME"/>
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:attribute name="nameFormat">
                        <xsl:choose>
                          <xsl:when test="$valueEmailTimeStamp=1">
                            <xsl:if test="$valueEmailAddFileName!=''">
                              <xsl:text>custom-date</xsl:text>
                            </xsl:if>
                            <xsl:if test="$valueEmailAddFileName=''">
                              <xsl:text>standard-date</xsl:text>
                            </xsl:if>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:if test="$valueEmailAddFileName!=''">
                              <xsl:text>custom</xsl:text>
                            </xsl:if>
                            <xsl:if test="$valueEmailAddFileName=''">
                              <xsl:text>standard</xsl:text>
                            </xsl:if>
                          </xsl:otherwise>
                        </xsl:choose>
                      </xsl:attribute>
                      <!--ファイル名に変数が使われている場合は変換フォーマットの変換が必要
												下記ではデフォルトのファイル名を入力-->
                      <xsl:choose>
                        <xsl:when test="contains($valueEmailAddFileName, '&lt;!--$') and contains($valueEmailAddFileName, '$--&gt;')">
                          <xsl:variable name="temp">
                            <xsl:call-template name="replace">
                              <xsl:with-param name="str" select="$valueEmailAddFileName"/>
                              <xsl:with-param name="match" select="'&lt;!--$'"/>
                              <xsl:with-param name="replace" select="'${'"/>
                            </xsl:call-template>
                          </xsl:variable>
                          <xsl:call-template name="replace">
                            <xsl:with-param name="str" select="$temp"/>
                            <xsl:with-param name="match" select="'$--&gt;'"/>
                            <xsl:with-param name="replace" select="'}'"/>
                          </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:value-of select="$valueEmailAddFileName"/>
                        </xsl:otherwise>
                      </xsl:choose>
                    </eMailFileName>
                  </xsl:if>
                  <!--
                  <xsl:if test="$Agent ='FILE'">
                  -->
                  <!--
                  <xsl:if test="$Agent!='EMAIL'">
                  -->
                  <xsl:if test="$Agent ='FILE' or $Agent='FILE and EMAIL'">
                    <saveFileName>
                      <xsl:variable name="valueFileTimeStamp">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="FILEAGT/TIMESTAMP"/>
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:variable name="valueName1">
                        <xsl:call-template name="trim">
                          <xsl:with-param name="s" select="FILEAGT/NAME1"/>
                        </xsl:call-template>
                      </xsl:variable>
                      <xsl:attribute name="nameFormat">
                        <xsl:choose>
                          <xsl:when test="$valueFileTimeStamp=1">
                            <xsl:if test="$valueName1!=''">
                              <xsl:text>custom-date</xsl:text>
                            </xsl:if>
                            <xsl:if test="$valueName1=''">
                              <xsl:text>standard-date</xsl:text>
                            </xsl:if>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:if test="$valueName1!=''">
                              <xsl:text>custom</xsl:text>
                            </xsl:if>
                            <xsl:if test="$valueName1=''">
                              <xsl:text>standard</xsl:text>
                            </xsl:if>
                          </xsl:otherwise>
                        </xsl:choose>
                      </xsl:attribute>
                      <xsl:choose>
                        <xsl:when test="contains($valueName1, '&lt;!--$') and contains($valueName1, '$--&gt;')">
                          <xsl:variable name="temp">
                            <xsl:call-template name="replace">
                              <xsl:with-param name="str" select="$valueName1"/>
                              <xsl:with-param name="match" select="'&lt;!--$'"/>
                              <xsl:with-param name="replace" select="'${'"/>
                            </xsl:call-template>
                          </xsl:variable>
                          <xsl:call-template name="replace">
                            <xsl:with-param name="str" select="$temp"/>
                            <xsl:with-param name="match" select="'$--&gt;'"/>
                            <xsl:with-param name="replace" select="'}'"/>
                          </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:value-of select="$valueName1"/>
                        </xsl:otherwise>
                      </xsl:choose>
                    </saveFileName>
                  </xsl:if>

                  <!--テンプレートに拡張フィールドを設定する-->
                  <xsl:variable name="valueEDFtemplate">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="ENHANCEDSETTING"/>
                    </xsl:call-template>
                  </xsl:variable>

                  <xsl:choose>
                    <xsl:when test="$valueEDFtemplate!=''">
                      <!--テンプレートグループに設定されている拡張フィールド-->
                      <xsl:call-template name="makeEFDForTemplate">
                        <xsl:with-param name="valueGROUPID" select="$valueGROUPID"/>
                        <xsl:with-param name="valueTEMPLATEID" select="$valueTEMPLATEID"/>
                      </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                      <!--何も設定されなければ空要素を設定-->
                      <ExtendedFieldList>
                        <xsl:attribute name="listSize"></xsl:attribute>
                      </ExtendedFieldList>
                    </xsl:otherwise>
                  </xsl:choose>
                </Params>
                <OriginalKey>Queues/Scan</OriginalKey>
                <password>
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s"  select="TEMPLATE/PAS"/>
                  </xsl:call-template>
                </password>
              </Template>
            </xsl:if>
            <!--処理対象のテンプレートかどうか？-->
          </xsl:for-each>
        </TemplateList>
      </Group>
    </xsl:if>
    <!--MetaScanテンプレートのみに適用-->
  </xsl:template>

  <xsl:template name="makeEFDForTemplate">
    <xsl:param name="valueGROUPID"/>
    <xsl:param name="valueTEMPLATEID"/>
    <xsl:variable name="efd-list" select="//MASTERSETTING/MASTERGROUPID[not(.=following::MASTERGROUPID)]" />
    <xsl:for-each select="$efd-list">
      <xsl:variable name="valueMasterGroupId">
        <xsl:call-template name="trim">
          <xsl:with-param name="s" select="."/>
        </xsl:call-template>
      </xsl:variable>
      <xsl:if test="$valueGROUPID=$valueMasterGroupId">
        <ExtendedFieldList>
          <xsl:for-each select="/DBRoot/TemplateDB/TemplateRec/rec2/ENHANCEDSETTING">
            <xsl:variable name="valueMASTERGROUPID">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="MASTERGROUPID"/>
              </xsl:call-template>
            </xsl:variable>            
            <xsl:if test="$valueMASTERGROUPID=$valueMasterGroupId">
              <xsl:variable name="valueENHANTEMPGRPID">
                <xsl:call-template name="trim">
                  <xsl:with-param name="s" select="ENHANTEMPGRPID"/>
                </xsl:call-template>
              </xsl:variable>
              <xsl:attribute name="efdid">
                 <xsl:value-of select="format-number($valueENHANTEMPGRPID - 10000,'000')"/>
              </xsl:attribute>
            </xsl:if>
          </xsl:for-each>
          <xsl:attribute name="listSize">
            <xsl:value-of select="count(//MASTERSETTING[normalize-space(MASTERGROUPID)=$valueMasterGroupId])"/>
          </xsl:attribute>
          <xsl:for-each select="//MASTERSETTING">
            <xsl:variable name="valueMasterGroupId_temp">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="MASTERGROUPID"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:if test="$valueMasterGroupId=$valueMasterGroupId_temp">
              <ExtendedField>
                <xsl:variable name="index">
                  <xsl:number count="MASTERSETTING[normalize-space(MASTERGROUPID)=$valueMasterGroupId]" />
                </xsl:variable>
                <PrimaryKey>
                  <xsl:value-of select="$index"/>
                </PrimaryKey>
                <!--
                <DisplayName>
                  <xsl:variable name="valueMASTERDISPLAY">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERDISPLAYNAME"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMASTERDISPLAY=''">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERFIELDNAME" />
                      </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$valueMASTERDISPLAY!=''">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERDISPLAYNAME" />
                      </xsl:call-template>
                    </xsl:when>
                  </xsl:choose> 
                </DisplayName>
                <FieldName>
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="MASTERFIELDNAME" />
                  </xsl:call-template>
                </FieldName>
                <IsMandatory>
                  <xsl:variable name="valueMasterMandattr">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMANDATTR"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMasterMandattr=1">true</xsl:when>
                    <xsl:otherwise>false</xsl:otherwise>
                  </xsl:choose>
                </IsMandatory>
                <IsHidden>
                  <xsl:variable name="valueMasterHidnattr">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERHIDNATTR"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMasterHidnattr=1">true</xsl:when>
                    <xsl:otherwise>false</xsl:otherwise>
                  </xsl:choose>
                </IsHidden>
                <xsl:variable name="valueInputMethod">
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="MASTERFIELDTYPE"/>
                  </xsl:call-template>
                </xsl:variable>
                <InputMethod>
                  <xsl:choose>
                    <xsl:when test="$valueInputMethod=0">Text</xsl:when>
                    <xsl:when test="$valueInputMethod=1">Numerical</xsl:when>
                    <xsl:when test="$valueInputMethod=2">Decimal</xsl:when>
                    <xsl:when test="$valueInputMethod=3">List</xsl:when>
                    <xsl:when test="$valueInputMethod=4">Address</xsl:when>
                    <xsl:when test="$valueInputMethod=5">Password</xsl:when>
                    <xsl:when test="$valueInputMethod=6">Date</xsl:when>
                    <xsl:otherwise>Text</xsl:otherwise>
                  </xsl:choose>
                </InputMethod>
                <xsl:variable name="valueDefaultValue">
                  <xsl:for-each select="/DBRoot/TemplateDB/TemplateRec/rec2/ENHANCEDSETTING">
                    <xsl:variable name="valueENHANTEMPID">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="ENHANTEMPID"/>
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="valueENHANCEDINDEX">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="ENHANCEDINDEX"/>
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:if test="$valueENHANTEMPID=$valueTEMPLATEID and $valueENHANCEDINDEX=$index">
                      <xsl:value-of select="ENHANSETVAL"/>
                    </xsl:if>
                  </xsl:for-each>
                </xsl:variable>
                <xsl:if test="$valueInputMethod=3">
                  <ListItems>
                    <xsl:call-template name="ListItems">
                      <xsl:with-param name="valueListData" select="MASTERLISTDATA"/>
                      <xsl:with-param name="valueDefault" select="$valueDefaultValue"/>
                    </xsl:call-template>
                  </ListItems>
                </xsl:if>
                <MinimumLength>
                  <xsl:variable name="valueMinLength">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMINDIGITS"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod='' or $valueInputMethod=0) and $valueMinLength =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERMINDIGITS" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MinimumLength>
                <MaximumLength>
                  <xsl:variable name="valueMaxLength">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMAXDIGITS"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod='' or $valueInputMethod=0) and $valueMaxLength =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERMAXDIGITS" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MaximumLength>
                <MinimumValue>
                  <xsl:variable name="valueMinValue">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMINVAL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                   <xsl:when test="($valueInputMethod=1 or $valueInputMethod=2) and $valueMinValue =''">0</xsl:when>
                   <xsl:otherwise>
                     <xsl:call-template name="minmaxconv">
                       <xsl:with-param name="valueMinMax" select="MASTERMINVAL"/>
                     </xsl:call-template>
                   </xsl:otherwise>
                  </xsl:choose>
                </MinimumValue>
                <MaximumValue>
                  <xsl:variable name="valueMaxValue">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMAXVAL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod=1 or $valueInputMethod=2) and $valueMaxValue =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="minmaxconv">
                        <xsl:with-param name="valueMinMax" select="MASTERMAXVAL"/>
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MaximumValue>
                <Value>
                  <xsl:choose>
                    <xsl:when test="$valueInputMethod=3">
                      <xsl:value-of select="substring-before($valueDefaultValue,';')"/>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="$valueDefaultValue" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </Value>  
                 -->
                <xsl:variable name="valueDefaultValue">
                  <xsl:for-each select="/DBRoot/TemplateDB/TemplateRec/rec2/ENHANCEDSETTING">
                    <xsl:variable name="valueENHANTEMPID">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="ENHANTEMPID"/>
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="valueENHANCEDINDEX">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="ENHANCEDINDEX"/>
                      </xsl:call-template>
                    </xsl:variable>
                    <xsl:if test="$valueENHANTEMPID=$valueTEMPLATEID and $valueENHANCEDINDEX=$index">
                      <xsl:value-of select="ENHANSETVAL"/>
                    </xsl:if>
                  </xsl:for-each>
                </xsl:variable>
                <xsl:variable name="valueKey">
                  <xsl:call-template name="ValueKeyCount">
                    <xsl:with-param name="valueDefault" select="$valueDefaultValue"/>
                    <xsl:with-param name="valueITEMS" select="MASTERLISTDATA"/>
                    <xsl:with-param name="count" select="0"/>
                  </xsl:call-template>
                </xsl:variable>
                <!--                
                <Value>
                  <xsl:value-of select="$valueKey"/>
                </Value>
                -->
                <xsl:variable name="valueInputMethod">
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="MASTERFIELDTYPE"/>
                  </xsl:call-template>
                </xsl:variable>
                <Value>
                  <xsl:choose>
                    <xsl:when test="$valueInputMethod=3 and $valueKey != 0">
                      <xsl:value-of select="$valueKey"/>
                    </xsl:when>
                    <xsl:when test="$valueInputMethod=3 and $valueKey = 0"></xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="$valueDefaultValue" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </Value>               
              </ExtendedField>
            </xsl:if>
          </xsl:for-each>
        </ExtendedFieldList>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <!--Extended Field Definitionを定義する-->
  <xsl:template match="DBRoot/TemplateDB/MASTERDATA">
    <xsl:variable name="efd-list" select="//MASTERSETTING/MASTERGROUPID[not(.=following::MASTERGROUPID)]" />
    <xsl:for-each select="$efd-list">
      <ExtendedFieldDefinition>
        <!--MASTERGROUPID-->
        <xsl:variable name="valueMasterGroupId">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="."/>
          </xsl:call-template>
        </xsl:variable>
        <!--EFDNameとXMLFormatFile-->
        <xsl:for-each select="/DBRoot/TemplateDB/SCNGRP/rec">
          <xsl:variable name="valueGroupID">
            <xsl:call-template name="trim">
              <xsl:with-param name="s"  select="GROUPID"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:variable name="valueUIDISPID">
            <xsl:call-template name="trim">
              <xsl:with-param name="s" select="UIDISPID"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:if test="$valueMasterGroupId=$valueGroupID">
            <xsl:attribute name="efdid">
              <xsl:value-of select="format-number($valueUIDISPID - 10000,'000')"/>
            </xsl:attribute>
            <EFDName>
              <xsl:text>definition</xsl:text>
              <xsl:value-of select="format-number($valueUIDISPID - 10000,'000')"/>
            </EFDName>
            <XMLFormatFile>
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="XMLFILEFORMAT"/>
              </xsl:call-template>
            </XMLFormatFile>
          </xsl:if>
        </xsl:for-each>
        <ExtendedFieldList>
          <xsl:attribute name="listSize">
            <xsl:value-of select="count(//MASTERSETTING[normalize-space(MASTERGROUPID)=$valueMasterGroupId])"/>
          </xsl:attribute>
          <!--コンカレントノードは全MASTERSETTINGに対して-->
          <xsl:for-each select="//MASTERSETTING">
            <xsl:variable name="valueMasterGroupId_temp">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="MASTERGROUPID"/>
              </xsl:call-template>
            </xsl:variable>
            <!--同じMASTERGROUPIDをもつもののみを処理する-->
            <xsl:if test="$valueMasterGroupId=$valueMasterGroupId_temp">
              <ExtendedField>
                <PrimaryKey>
                  <xsl:number count="MASTERSETTING[normalize-space(MASTERGROUPID)=$valueMasterGroupId]" />
                </PrimaryKey>                
                <DisplayName>
                  <xsl:variable name="valueMASTERDISPLAY">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERDISPLAYNAME"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMASTERDISPLAY=''">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERFIELDNAME" />
                      </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$valueMASTERDISPLAY!=''">
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERDISPLAYNAME" />
                      </xsl:call-template>
                    </xsl:when>
                  </xsl:choose>
                </DisplayName>
                <FieldName>
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="MASTERFIELDNAME" />
                  </xsl:call-template>
                </FieldName>
                <IsMandatory>
                  <xsl:variable name="valueMasterMandattr">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMANDATTR"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMasterMandattr=1">true</xsl:when>
                    <xsl:otherwise>false</xsl:otherwise>
                  </xsl:choose>
                </IsMandatory>
                <IsHidden>
                  <xsl:variable name="valueMasterHidnattr">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERHIDNATTR"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueMasterHidnattr=1">true</xsl:when>
                    <xsl:otherwise>false</xsl:otherwise>
                  </xsl:choose>
                </IsHidden>
                <xsl:variable name="valueInputMethod">
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s" select="MASTERFIELDTYPE"/>
                  </xsl:call-template>
                </xsl:variable>
                <InputMethod>
                  <xsl:choose>
                    <xsl:when test="$valueInputMethod=0">Text</xsl:when>
                    <xsl:when test="$valueInputMethod=1">Numerical</xsl:when>
                    <xsl:when test="$valueInputMethod=2">Decimal</xsl:when>
                    <xsl:when test="$valueInputMethod=3">List</xsl:when>
                    <xsl:when test="$valueInputMethod=4">Address</xsl:when>
                    <xsl:when test="$valueInputMethod=5">Password</xsl:when>
                    <xsl:when test="$valueInputMethod=6">Date</xsl:when>
                    <xsl:otherwise>Text</xsl:otherwise>
                  </xsl:choose>
                </InputMethod>
                <xsl:if test="$valueInputMethod=3">
                  <ListItems>
                    <xsl:call-template name="ListItems">
                      <xsl:with-param name="valueListData" select="MASTERLISTDATA"/>
                      <xsl:with-param name="valueDefault" select="MASTERSETVAL"/>
                    </xsl:call-template>
                  </ListItems>
                </xsl:if>
                <MinimumLength>
                  <xsl:variable name="valueMinLength">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMINDIGITS"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod='' or $valueInputMethod=0) and $valueMinLength =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERMINDIGITS" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MinimumLength>
                <MaximumLength>
                  <xsl:variable name="valueMaxLength">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMAXDIGITS"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod='' or $valueInputMethod=0) and $valueMaxLength =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERMAXDIGITS" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MaximumLength>
                <MinimumValue>
                  <xsl:variable name="valueMinValue">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMINVAL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod=1 or $valueInputMethod=2) and $valueMinValue =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="minmaxconv">
                        <xsl:with-param name="valueMinMax" select="MASTERMINVAL"/>
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MinimumValue>
                <MaximumValue>
                  <xsl:variable name="valueMaxValue">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s" select="MASTERMAXVAL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="($valueInputMethod=1 or $valueInputMethod=2) and $valueMaxValue =''">0</xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="minmaxconv">
                        <xsl:with-param name="valueMinMax" select="MASTERMAXVAL"/>
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </MaximumValue>
                <DefaultValue>
                  <xsl:choose>
                    <xsl:when test="$valueInputMethod=3">
                      <xsl:value-of select="substring-before(MASTERSETVAL,';')"/>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="trim">
                        <xsl:with-param name="s" select="MASTERSETVAL" />
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </DefaultValue>
              </ExtendedField>
            </xsl:if>
          </xsl:for-each>
        </ExtendedFieldList>
      </ExtendedFieldDefinition>
    </xsl:for-each>
  </xsl:template>

  <!--MAILエージェントへの適用-->
  <xsl:template match="MAILAGT">
    <EmailSend>
      <xsl:attribute name="Enabled">true</xsl:attribute>
      <EmailSendParameter>
        <!--テンプレートのMAILAGTIDを格納-->
        <xsl:variable name="valueREC2ID">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="ID"/>
          </xsl:call-template>
        </xsl:variable>
        <To>
          <!--valueREC2IDを持つrec3IDをToに設定-->
          <xsl:for-each select="/DBRoot/TemplateDB/TEMPDEST/rec3">
            <xsl:variable name="valueREC3ID">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="ID"/>
              </xsl:call-template>
            </xsl:variable>
            <!--空文字:Toか１:CCかを判断-->
            <xsl:variable name="valueREC3DESTKIND">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="DESTKIND"/>
              </xsl:call-template>
            </xsl:variable>
            <!--宛先がToの場合-->
            <xsl:if test="$valueREC2ID=$valueREC3ID and $valueREC3DESTKIND=''">
              <xsl:variable name="valueIndexTo">
                <xsl:number format="1" level="any"
											count="/DBRoot/TemplateDB/TEMPDEST/rec3[normalize-space(ID)=$valueREC2ID and normalize-space(DESTKIND)='']"/>
              </xsl:variable>
              <EmailDestinationInformation>
                <xsl:attribute name="Index">
                  <xsl:value-of select="$valueIndexTo"/>
                </xsl:attribute>
                <EmailAddress>
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s"  select="MAIL"/>
                  </xsl:call-template>
                </EmailAddress>
                <ContactID>
                  <xsl:variable name="valueADRID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="ADRID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:if test="$valueADRID=''"></xsl:if>
                  <xsl:if test="$valueADRID!=''">
                    <xsl:value-of select="format-number($valueADRID, '0000')"/>
                  </xsl:if>
                </ContactID>
                <ContactName></ContactName>
                <GroupID>
                  <xsl:variable name="valueGROUPID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="GROUPID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:if test="$valueGROUPID=''"></xsl:if>
                  <xsl:if test="$valueGROUPID!=''">
                    <xsl:value-of select="format-number($valueGROUPID, '000')"/>
                  </xsl:if>
                </GroupID>
                <GroupName/>
                <DestinationInputMethod>
                  <xsl:variable name="valueADRID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="ADRID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="valueGRPID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="GROUPID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="valueMAIL">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="MAIL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueADRID !=''">AddressBook</xsl:when>
                    <xsl:when test="$valueGRPID !=''">AddressBook</xsl:when>
                    <xsl:when test="$valueMAIL !=''">Manual</xsl:when>
                    <xsl:otherwise>Manual</xsl:otherwise>
                  </xsl:choose>
                </DestinationInputMethod>
              </EmailDestinationInformation>
            </xsl:if>
          </xsl:for-each>
        </To>
        <Cc>
          <!--valueREC2IDを持つrec3IDをCCに設定-->
          <xsl:for-each select="/DBRoot/TemplateDB/TEMPDEST/rec3">
            <xsl:variable name="valueREC3ID">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="ID"/>
              </xsl:call-template>
            </xsl:variable>
            <!--空文字:Toか１:CCかを判断-->
            <xsl:variable name="valueREC3DESTKIND">
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="DESTKIND"/>
              </xsl:call-template>
            </xsl:variable>
            <!--宛先がCCの場合-->
            <xsl:if test="$valueREC2ID=$valueREC3ID and $valueREC3DESTKIND='1'">
              <xsl:variable name="valueIndexCC">
                <xsl:number format="1" level="any"
											count="/DBRoot/TemplateDB/TEMPDEST/rec3[normalize-space(ID)=$valueREC2ID and normalize-space(DESTKIND)='1']"/>
              </xsl:variable>
              <EmailDestinationInformation>
                <xsl:attribute name="Index">
                  <xsl:value-of select="$valueIndexCC"/>
                </xsl:attribute>
                <EmailAddress>
                  <xsl:call-template name="trim">
                    <xsl:with-param name="s"  select="MAIL"/>
                  </xsl:call-template>
                </EmailAddress>
                <ContactID>
                  <xsl:variable name="valueADRID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="ADRID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:if test="$valueADRID=''"></xsl:if>
                  <xsl:if test="$valueADRID!=''">
                    <xsl:value-of select="format-number($valueADRID, '0000')"/>
                  </xsl:if>
                </ContactID>
                <ContactName></ContactName>
                <GroupID>
                  <xsl:variable name="valueGROUPID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="GROUPID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:if test="$valueGROUPID=''"></xsl:if>
                  <xsl:if test="$valueGROUPID!=''">
                    <xsl:value-of select="format-number($valueGROUPID, '000')"/>
                  </xsl:if>
                </GroupID>
                <GroupName></GroupName>
                <DestinationInputMethod>
                  <xsl:variable name="valueADRID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="ADRID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="valueGRPID">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="GROUPID"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="valueMAIL">
                    <xsl:call-template name="trim">
                      <xsl:with-param name="s"  select="MAIL"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$valueADRID!=''">AddressBook</xsl:when>
                    <xsl:when test="$valueGRPID!=''">AddressBook</xsl:when>
                    <xsl:when test="$valueMAIL!=''">Manual</xsl:when>
                    <xsl:otherwise>Manual</xsl:otherwise>
                  </xsl:choose>
                </DestinationInputMethod>
              </EmailDestinationInformation>
            </xsl:if>
          </xsl:for-each>
        </Cc>
        <!--テンプレートに設定されている宛先に対応するMAIL情報をrec3から取り出す-->
        <Subject>
          <xsl:variable name="valueSubjectInputMethod">
            <xsl:value-of select="SUBJECTFORMAT"/>
          </xsl:variable>
          <xsl:attribute name="SubjectInputMethod">
            <xsl:choose>
              <!--固定フォーマットの場合-->
              <xsl:when test="$valueSubjectInputMethod=1">ScannedFromDeviceName</xsl:when>
              <xsl:otherwise>ManualInput</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:call-template name="trim">
            <xsl:with-param name="s"  select="SUBJECT"/>
          </xsl:call-template>
        </Subject>
        <Body>
          <UserText>
            <xsl:call-template name="trim">
              <xsl:with-param name="s"  select="BODYSTRIN"/>
            </xsl:call-template>
          </UserText>
        </Body>
        <FromName>
          <xsl:attribute name="FromNameInputMethod">
            <xsl:variable name="ValueFromName">
              <xsl:call-template name="trim">
                <xsl:with-param name="s"  select="FROMNAME"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="$ValueFromName=''">ScannedFromDeviceName</xsl:when>
              <xsl:otherwise>ManualInput</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>          
          <xsl:call-template name="trim">
            <xsl:with-param name="s"  select="FROMNAME"/>
          </xsl:call-template>
        </FromName>        
        <FromAddress>
          <xsl:attribute name="FromAddressInputMethod">
            <xsl:variable name="ValueFromAddr">
              <xsl:call-template name="trim">
                <xsl:with-param name="s"  select="FROMADR"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="$ValueFromAddr=''">ScannedFromDeviceName</xsl:when>
              <xsl:otherwise>ManualInput</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:call-template name="trim">
            <xsl:with-param name="s"  select="FROMADR"/>
          </xsl:call-template>
        </FromAddress>
        <FragmentSize>
          <xsl:variable name="valueFragmentSize">
            <xsl:call-template name="trim">
              <xsl:with-param name="s"  select="PARTIAL"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:choose>
            <xsl:when test="$valueFragmentSize=''">Unused</xsl:when>
            <xsl:when test="$valueFragmentSize=64">64KB</xsl:when>
            <xsl:when test="$valueFragmentSize=128">128KB</xsl:when>
            <xsl:when test="$valueFragmentSize=256">256KB</xsl:when>
            <xsl:when test="$valueFragmentSize=512">512KB</xsl:when>
            <xsl:when test="$valueFragmentSize=1024">1024KB</xsl:when>
            <xsl:when test="$valueFragmentSize=2048">2048KB</xsl:when>
            <xsl:otherwise>Unused</xsl:otherwise>
          </xsl:choose>
        </FragmentSize>
        <!--Do not create tag <TotalPages>1</TotalPages>-->
        <FileFormatInformation>
          <FileFormat>
            <!--FileFormatを求める-->
            <xsl:call-template name="FileFormat">
              <xsl:with-param name="valueFileFormat" select="FILEFORMAT"/>
            </xsl:call-template>
          </FileFormat>
          <!--SecurePDF要素の処理-->
          <xsl:call-template name="SecurePDF"/>
        </FileFormatInformation>
        <TimeStampOnSubject>
          <xsl:variable name="TimeStampValue">
            <xsl:call-template name="trim">
              <xsl:with-param name="s"  select="SUBJECTTIMESTAMP"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:choose>
            <xsl:when test="$TimeStampValue=1">true</xsl:when>
            <xsl:otherwise>false</xsl:otherwise>
          </xsl:choose>
        </TimeStampOnSubject>
      </EmailSendParameter>
    </EmailSend>
  </xsl:template>

  <!--Save as Fileエージェントへの適用-->
  <xsl:template match="FILEAGT">
    <!--localが設定されているか確認する(空文字:無効 1:共有フォルダ 2:リモートサーバ) -->
    <xsl:variable name="valueLOCAT1">
      <xsl:call-template name="trim">
        <xsl:with-param name="s"  select="LOCAT1"/>
      </xsl:call-template>
    </xsl:variable>

    <!--Remote1が設定されているか確認する(空文字:無効 1:共有フォルダ 2:リモートサーバ) -->
    <xsl:variable name="valueLOCAT2">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="LOCAT2"/>
      </xsl:call-template>
    </xsl:variable>

    <!--Remote2が設定されているか確認する(空文字:無効 1:共有フォルダ 2:リモートサーバ) -->
    <xsl:variable name="valueLOCAT3">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="LOCAT3"/>
      </xsl:call-template>
    </xsl:variable>

    <!--
			テンプレートに設定する宛先を決める
			$valueDestination=[local or remote1 or remote2]
		-->
    <xsl:variable name="valueDestination">
      <xsl:choose>
        <!--共有フォルダのみ-->
        <xsl:when test="$valueLOCAT1 !='' and $valueLOCAT2 ='' and $valueLOCAT3 =''">
          <xsl:text>local</xsl:text>
        </xsl:when>
        <!--Remote1のみ-->
        <xsl:when test="$valueLOCAT1 ='' and $valueLOCAT2 !='' and $valueLOCAT3 =''">
          <xsl:text>remote1</xsl:text>
        </xsl:when>
        <!--Remote2のみ-->
        <xsl:when test="$valueLOCAT1 ='' and $valueLOCAT2 ='' and $valueLOCAT3 !=''">
          <xsl:text>remote2</xsl:text>
        </xsl:when>
        <!--複数宛先が設定されている場合-->
        <!--priorityDestinationの値によって選択先を変える-->
        <xsl:otherwise>
          <!--local > remote1 > remote2-->
          <xsl:if test="$priorityDestination ='lr1r2'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT1 !=''">local</xsl:when>
              <xsl:when test="$valueLOCAT2 !=''">remote1</xsl:when>
              <xsl:otherwise>remote2</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
          <!--local > remote2 > remote1-->
          <xsl:if test="$priorityDestination = 'lr2r1'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT1 !=''">local</xsl:when>
              <xsl:when test="$valueLOCAT3 !=''">remote2</xsl:when>
              <xsl:otherwise>remote1</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
          <!--remote1 > remote2 > local-->
          <xsl:if test="$priorityDestination = 'r1r2l'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT2 != ''">remote1</xsl:when>
              <xsl:when test="$valueLOCAT3 != ''">remote2</xsl:when>
              <xsl:otherwise>local</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
          <!--remote1 > local > remote2-->
          <xsl:if test="$priorityDestination = 'r1lr2'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT2 != ''">remote1</xsl:when>
              <xsl:when test="$valueLOCAT1 != ''">local</xsl:when>
              <xsl:otherwise>remote2</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
          <!--remote2 > remote1 > local-->
          <xsl:if test="$priorityDestination='r2r1l'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT3 !=''">remote2</xsl:when>
              <xsl:when test="$valueLOCAT2 !=''">remote1</xsl:when>
              <xsl:otherwise>local</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
          <!--remote2 > local > remote1-->
          <xsl:if test="$priorityDestination='r2lr1'">
            <xsl:choose>
              <xsl:when test="$valueLOCAT3 !=''">remote2</xsl:when>
              <xsl:when test="$valueLOCAT1 !=''">local</xsl:when>
              <xsl:otherwise>remote1</xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:choose>
      <!--local folderのみ設定されていた場合-->
      <xsl:when test="$valueDestination='local'">
        <LocalStore>
          <xsl:attribute name="Enabled">
            <xsl:text>true</xsl:text>
          </xsl:attribute>
          <LocalStoreParameter>
            <FileFormatInformation>
              <FileFormat>
                <!--FileFormatを求める-->
                <xsl:call-template name="FileFormat">
                  <xsl:with-param name="valueFileFormat" select="FORMAT1"/>
                </xsl:call-template>
              </FileFormat>
              <!--SecurePDF作成用-->
              <xsl:call-template name="SecurePDF"/>
            </FileFormatInformation>
          </LocalStoreParameter>
        </LocalStore>
      </xsl:when>
      <!--remote1が設定されていた場合-->
      <xsl:when test="$valueDestination='remote1'">
        <!--Remote1のプロトコル -->
        <xsl:variable name="valueTRANPORT2">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="TRANPORT2"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:choose>
          <!--プロトコル毎にノードを作成する-->
          <!--FTPの場合-->
          <xsl:when test="$valueTRANPORT2=1">
            <xsl:call-template name="FTP">
              <xsl:with-param name="paramFileName" select="NAME2"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT2"/>
              <xsl:with-param name="paramServerName" select="SNAME2"/>
              <xsl:with-param name="paramStorePath" select="PATH2"/>
              <xsl:with-param name="paramCommandPort" select="CPORT2"/>
              <xsl:with-param name="paramUserName" select="UNAME2"/>
              <xsl:with-param name="paramPassword" select="PASS2"/>
              <xsl:with-param name="paramIndex" select="1"/>
            </xsl:call-template>
          </xsl:when>
          <!--SMBの場合-->
          <xsl:when test="$valueTRANPORT2=2">
            <xsl:call-template name="SMB">
              <xsl:with-param name="paramFileName" select="NAME2"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT2"/>
              <xsl:with-param name="paramStorePath" select="PATH2"/>
              <xsl:with-param name="paramUserName" select="UNAME2"/>
              <xsl:with-param name="paramPassword" select="PASS2"/>
              <xsl:with-param name="paramIndex" select="1"/>
            </xsl:call-template>
          </xsl:when>
          <!--IPX/SPXまたはNetwareの場合-->
          <xsl:when test="$valueTRANPORT2=3 or $valueTRANPORT2=8">
            <xsl:call-template name="Netware">
              <xsl:with-param name="paramFileName" select="NAME2"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT2"/>
              <xsl:with-param name="paramServerName" select="SNAME2"/>
              <xsl:with-param name="paramStorePath" select="PATH2"/>
              <xsl:with-param name="paramUserName" select="UNAME2"/>
              <xsl:with-param name="paramPassword" select="PASS2"/>
              <xsl:with-param name="paramNetwareForwardingProtocol" select="TRANPORT2"/>
              <xsl:with-param name="paramIndex" select="1"/>
            </xsl:call-template>
          </xsl:when>
        </xsl:choose>
      </xsl:when>
      <!--remote2が設定されていた場合-->
      <xsl:when test="$valueDestination='remote2'">
        <!--Remote2のプロトコル -->
        <xsl:variable name="valueTRANPORT3">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="TRANPORT3"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:choose>
          <!--プロトコル毎にノードを作成する-->
          <!--FTPの場合-->
          <xsl:when test="$valueTRANPORT3=1">
            <xsl:call-template name="FTP">
              <xsl:with-param name="paramFileName" select="NAME3"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT3"/>
              <xsl:with-param name="paramServerName" select="SNAME3"/>
              <xsl:with-param name="paramStorePath" select="PATH3"/>
              <xsl:with-param name="paramCommandPort" select="CPORT3"/>
              <xsl:with-param name="paramUserName" select="UNAME3"/>
              <xsl:with-param name="paramPassword" select="PASS3"/>
              <xsl:with-param name="paramIndex" select="2"/>
            </xsl:call-template>
          </xsl:when>
          <!--SMBの場合-->
          <xsl:when test="$valueTRANPORT3=2">
            <xsl:call-template name="SMB">
              <xsl:with-param name="paramFileName" select="NAME3"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT3"/>
              <xsl:with-param name="paramStorePath" select="PATH3"/>
              <xsl:with-param name="paramUserName" select="UNAME3"/>
              <xsl:with-param name="paramPassword" select="PASS3"/>
              <xsl:with-param name="paramIndex" select="2"/>
            </xsl:call-template>
          </xsl:when>
          <!--IPX/SPXまたはNetwareの場合-->
          <xsl:when test="$valueTRANPORT3=3 or $valueTRANPORT3=8">
            <xsl:call-template name="Netware">
              <xsl:with-param name="paramFileName" select="NAME3"/>
              <xsl:with-param name="paramTIMESTAMP" select="TIMESTAMP"/>
              <xsl:with-param name="paramFORMAT" select="FORMAT3"/>
              <xsl:with-param name="paramServerName" select="SNAME3"/>
              <xsl:with-param name="paramStorePath" select="PATH3"/>
              <xsl:with-param name="paramUserName" select="UNAME3"/>
              <xsl:with-param name="paramPassword" select="PASS3"/>
              <xsl:with-param name="paramNetwareForwardingProtocol" select="TRANPORT3"/>
              <xsl:with-param name="paramIndex" select="2"/>
            </xsl:call-template>
          </xsl:when>
        </xsl:choose>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!--FTPノード作成用-->
  <xsl:template name="FTP">
    <xsl:param name="paramFileName"/>
    <xsl:param name="paramTIMESTAMP"/>
    <xsl:param name="paramFORMAT"/>
    <xsl:param name="paramServerName"/>
    <xsl:param name="paramStorePath"/>
    <xsl:param name="paramCommandPort"/>
    <xsl:param name="paramUserName" />
    <xsl:param name="paramPassword"/>
    <xsl:param name="paramIndex"/>
    <FTPStore Enabled="true">
      <xsl:attribute name="Index">
        <xsl:value-of select="$paramIndex"/>
      </xsl:attribute>
      <FTPStoreParameter>
        <FileFormatInformation>
          <FileFormat>
            <xsl:call-template name="FileFormat">
              <xsl:with-param name="valueFileFormat" select="$paramFORMAT"/>
            </xsl:call-template>
          </FileFormat>

          <!--SecurePDF作成用-->
          <xsl:call-template name="SecurePDF"/>

        </FileFormatInformation>
        <ServerName>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramServerName"/>
          </xsl:call-template>
        </ServerName>
        <StorePath>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramStorePath"/>
          </xsl:call-template>
        </StorePath>
        <CommandPort>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramCommandPort"/>
          </xsl:call-template>
        </CommandPort>
        <UserName>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramUserName" />
          </xsl:call-template>
        </UserName>
        <Password>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramPassword" />
          </xsl:call-template>
        </Password>
        <SSL>false</SSL>
      </FTPStoreParameter>
    </FTPStore>
  </xsl:template>

  <!--SMBノード作成用-->
  <xsl:template name="SMB">
    <xsl:param name="paramFileName"/>
    <xsl:param name="paramTIMESTAMP"/>
    <xsl:param name="paramFORMAT"/>
    <xsl:param name="paramStorePath"/>
    <xsl:param name="paramUserName" />
    <xsl:param name="paramPassword"/>
    <xsl:param name="paramIndex"/>
    <SMBStore Enabled="true">
      <xsl:attribute name="Index">
        <xsl:value-of select="$paramIndex"/>
      </xsl:attribute>
      <SMBStoreParameter>
        <FileFormatInformation>
          <FileFormat>
            <!--FileFormatを求める-->
            <xsl:call-template name="FileFormat">
              <xsl:with-param name="valueFileFormat" select="$paramFORMAT"/>
            </xsl:call-template>
          </FileFormat>
          <!--securePDF作成用-->
          <xsl:call-template name="SecurePDF"/>
        </FileFormatInformation>
        <StorePath>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramStorePath"/>
          </xsl:call-template>
        </StorePath>
        <UserName>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramUserName"/>
          </xsl:call-template>
        </UserName>
        <Password>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramPassword"/>
          </xsl:call-template>
        </Password>
      </SMBStoreParameter>
    </SMBStore>
  </xsl:template>

  <!--NetWareノード作成用-->
  <xsl:template name="Netware">
    <xsl:param name="paramFileName"/>
    <xsl:param name="paramTIMESTAMP"/>
    <xsl:param name="paramFORMAT"/>
    <xsl:param name="paramServerName"/>
    <xsl:param name="paramStorePath"/>
    <xsl:param name="paramUserName" />
    <xsl:param name="paramPassword"/>
    <xsl:param name="paramNetwareForwardingProtocol"/>
    <xsl:param name="paramIndex"/>
    <NetwareStore Enabled="true">
      <xsl:attribute name="Index">
        <xsl:value-of select="$paramIndex"/>
      </xsl:attribute>
      <NetwareStoreParameter>
        <xsl:variable name="valueNetwareForwardingProtocol">
          <xsl:value-of select="$paramNetwareForwardingProtocol"/>
        </xsl:variable>
        <NetwareForwardingProtocol>
          <xsl:choose>
            <xsl:when test="$valueNetwareForwardingProtocol=3">IPX-SPX</xsl:when>
            <xsl:when test="$valueNetwareForwardingProtocol=8">TCP-IP</xsl:when>
            <xsl:otherwise>TCP-IP</xsl:otherwise>
          </xsl:choose>
        </NetwareForwardingProtocol>
        <FileFormatInformation>
          <FileFormat>
            <!--FileFormatを求める-->
            <xsl:call-template name="FileFormat">
              <xsl:with-param name="valueFileFormat" select="$paramFORMAT"/>
            </xsl:call-template>
          </FileFormat>
          <!--securePDF作成用-->
          <xsl:call-template name="SecurePDF"/>
        </FileFormatInformation>
        <ServerName>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramServerName"/>
          </xsl:call-template>
        </ServerName>
        <StorePath>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramStorePath"/>
          </xsl:call-template>
        </StorePath>
        <UserName>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramUserName"/>
          </xsl:call-template>
        </UserName>
        <Password>
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="$paramPassword"/>
          </xsl:call-template>
        </Password>
      </NetwareStoreParameter>
    </NetwareStore>
  </xsl:template>

  <!--テンプレートグループに登録されているテンプレートの数-->
  <xsl:template name="TemplateCount">
    <xsl:param name="valueUIDISPID"/>
    <!--MetaScanテンプレートの合計数-->
    <xsl:variable name="valueB3totalMetaScanltemplate">
      <xsl:value-of select="count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[normalize-space(GRPNUM)=$valueUIDISPID])"/>
    </xsl:variable>
    <!--UIの選択結果と、テンプレートに登録されているAgent、SaveAsFileの宛先によりテンプレートの合計数を変更-->
    <xsl:choose>
      <!--[selectedAgent]-[priorityDestination]-->
      <!--1.[FILE]-[優先度を選択]→テンプレートは減らない-->
      <xsl:when test="$selectedAgent = 'FILE' and $priorityDestination !='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate"/>
      </xsl:when>
      <!--2.[FILE]-[DoNotConvert]→FILEAgentに宛先が複数設定されている場合にテンプレートが変換されない-->
      <xsl:when test="$selectedAgent = 'FILE' and $priorityDestination ='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate - 
							  count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[normalize-space(GRPNUM)=$valueUIDISPID and
							  (normalize-space(FILEAGTID) != '' and
								((../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT2) != '']) or
								 (../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']) or
								 (../FILEAGT[normalize-space(LOCAT2) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']))
							  )])"/>
      </xsl:when>
      <!--3.[EMAIL]-[優先度を選択]→テンプレートは減らない-->
      <xsl:when test="$selectedAgent = 'EMAIL' and $priorityDestination !='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate"/>
      </xsl:when>
      <!--4.[EMAIL]-[DoNotConvert]→FILEAgentのみが設定され宛先が複数設定されているテンプレートが変換されない-->
      <xsl:when test="$selectedAgent = 'EMAIL' and $priorityDestination ='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate - 
							  count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[normalize-space(GRPNUM)=$valueUIDISPID and
							  (normalize-space(FILEAGTID) != '' and normalize-space(EMAILAGTID) = '' and 
								((../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT2) != '']) or
								 (../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']) or
								 (../FILEAGT[normalize-space(LOCAT2) != ''] and ../FILEAGT[normalize-space(LOCAT3) != ''])
								)
							  )])"/>
      </xsl:when>
      <!--5.[DoNotConvert]-[優先度あり]→複数Agentが設定されているもののみテンプレートが変換されない-->
      <xsl:when test="$selectedAgent = 'DoNotConvert' and $priorityDestination !='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate - 
							  count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[normalize-space(GRPNUM)=$valueUIDISPID and
							  (normalize-space(FILEAGTID) != '' and normalize-space(EMAILAGTID) != '')])"/>
      </xsl:when>
      <!--6.[DoNotConvert]-[DoNotConvert]→Agentが複数登録されているもの、Agentは1つだが、SaveasFileで2つ宛先が登録されているテンプレートが変換されない-->
      <xsl:when test="$selectedAgent = 'DoNotConvert' and $priorityDestination ='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate -
							  count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[
									(normalize-space(GRPNUM) = $valueUIDISPID) and
									(( normalize-space(FILEAGTID) != '' and normalize-space(EMAILAGTID) !='') or 
									((normalize-space(FILEAGTID) != '' and normalize-space(EMAILAGTID) = '') and
									((../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT2) != '']) or
									( ../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']) or
									( ../FILEAGT[normalize-space(LOCAT2) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']))
							  ))])"/>
      </xsl:when>
      <xsl:when test="$selectedAgent = 'FILE and EMAIL' and $priorityDestination !='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate"/>
      </xsl:when>
      <!--7.[EMAIL]-[DoNotConvert]→FILEAgentのみが設定され宛先が複数設定されているテンプレートが変換されない-->
      <xsl:when test="$selectedAgent = 'FILE and EMAIL' and $priorityDestination ='DoNotConvert'">
        <xsl:value-of select="$valueB3totalMetaScanltemplate - 
							  count(/DBRoot/TemplateDB/TemplateRec/rec2/TEMPLATE[normalize-space(GRPNUM)=$valueUIDISPID and
							  (normalize-space(FILEAGTID) != '' and normalize-space(EMAILAGTID) = '' and 
								((../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT2) != '']) or
								 (../FILEAGT[normalize-space(LOCAT1) != ''] and ../FILEAGT[normalize-space(LOCAT3) != '']) or
								 (../FILEAGT[normalize-space(LOCAT2) != ''] and ../FILEAGT[normalize-space(LOCAT3) != ''])
								)
							  )])"/>
      </xsl:when>
      <xsl:otherwise>0</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--MultiAgentかどうか-->
  <xsl:template name="MULTIAGENT">
    <xsl:variable name="valueEMAILAGTID">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="TEMPLATE/EMAILAGTID"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="valueFILEAGTID">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="TEMPLATE/FILEAGTID"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$valueEMAILAGTID != '' and $valueFILEAGTID !=''">
        <xsl:text>true</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>false</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--MultiDestinationかどうか-->
  <xsl:template name="MULTIDESTINATION">
    <xsl:variable name="valueFILEAGTID">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="TEMPLATE/FILEAGTID"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$valueFILEAGTID != ''">
        <xsl:variable name="valueLOCAT1">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="FILEAGT/LOCAT1"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="valueLOCAT2">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="FILEAGT/LOCAT2"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="valueLOCAT3">
          <xsl:call-template name="trim">
            <xsl:with-param name="s" select="FILEAGT/LOCAT3"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:choose>
          <xsl:when test="($valueLOCAT1 != '' and $valueLOCAT2 != '') or 
									($valueLOCAT1 != '' and $valueLOCAT3 != '') or
									($valueLOCAT2 != '' and $valueLOCAT3 != '')">
            <xsl:text>true</xsl:text>
          </xsl:when>
          <xsl:otherwise>false</xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>false</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--処理対象のテンプレートか？(true/false)-->
  <xsl:template name="eBXTEMPLATE">
    <xsl:param name="GRPNUM"/>
    <xsl:param name="UIDISPID"/>
    <xsl:choose>
      <xsl:when test="$GRPNUM = $UIDISPID">
        <xsl:choose>
          <!--[Agent]-[Priority]-->
          <!--1.[FILE]-[優先度を選択]→テンプレートは減らない-->
          <xsl:when test="$selectedAgent = 'FILE' and $priorityDestination !='DoNotConvert'">
            <xsl:text>true</xsl:text>
          </xsl:when>
          <!--2.[FILE]-[DoNotConvert]→FILEAgentに宛先が複数設定されている場合は処理対象外-->
          <xsl:when test="($selectedAgent = 'FILE' and $priorityDestination ='DoNotConvert' and
									 (TEMPLATE[normalize-space(FILEAGTID) != ''] and 
									((FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT2) != '']) or
									 (FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT3) != '']) or
									 (FILEAGT[normalize-space(LOCAT2) != ''] and FILEAGT[normalize-space(LOCAT3) != ''])))
									)">
            <xsl:text>false</xsl:text>
          </xsl:when>

          <!--3.[EMAIL]-[優先度を選択]→全てが処理対象-->
          <xsl:when test="$selectedAgent = 'EMAIL' and $priorityDestination !='DoNotConvert'">
            <xsl:text>true</xsl:text>
          </xsl:when>
          <!--4.[EMAIL]-[DoNotConvert]→FILEAgentのみが設定され宛先が複数設定されているテンプレートは処理対象外-->
          <xsl:when test="$selectedAgent = 'EMAIL' and $priorityDestination ='DoNotConvert' and
							  ((TEMPLATE[normalize-space(FILEAGTID) != ''] and TEMPLATE[normalize-space(EMAILAGTID) = '']) and 
								((FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT2) != '']) or
								 (FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT3) != '']) or
								 (FILEAGT[normalize-space(LOCAT2) != ''] and FILEAGT[normalize-space(LOCAT3) != '']))
							  )">
            <xsl:text>false</xsl:text>
          </xsl:when>
          <!--5.[DoNotConvert]-[優先度あり]→複数Agentが設定されていルテンプレートは処理対象外-->
          <xsl:when test="$selectedAgent = 'DoNotConvert' and $priorityDestination != 'DoNotConvert' and
							  (TEMPLATE[normalize-space(FILEAGTID) != ''] and TEMPLATE[normalize-space(EMAILAGTID) != ''])">
            <xsl:text>false</xsl:text>
          </xsl:when>
          <!--6.[DoNotConvert]-[DoNotConvert]→Agentが複数登録されているもの、Agentは1つだが、SaveasFileで2つ宛先が登録されているテンプレートは処理対象外-->
          <xsl:when test="$selectedAgent = 'DoNotConvert' and $priorityDestination ='DoNotConvert' and
							  (( TEMPLATE[normalize-space(FILEAGTID) != ''] and TEMPLATE[normalize-space(EMAILAGTID) !='']) or 
							   ((TEMPLATE[normalize-space(FILEAGTID) != ''] and TEMPLATE[normalize-space(EMAILAGTID) = '']) and
							    ((FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT2) != '']) or
								 (FILEAGT[normalize-space(LOCAT1) != ''] and FILEAGT[normalize-space(LOCAT3) != '']) or
								 (FILEAGT[normalize-space(LOCAT2) != ''] and FILEAGT[normalize-space(LOCAT3) != '']))
							    )
							  )">
            <xsl:text>false</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>true</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>false</xsl:otherwise>
      <!--Meta Scan template以外は処理対象外-->
    </xsl:choose>
  </xsl:template>

  <!--要素内の不要な空白を除去-->
  <xsl:template name="left-trim">
    <xsl:param name="s" />
    <xsl:choose>
      <xsl:when test="substring($s, 1, 1) = ''">
        <xsl:value-of select="$s"/>
      </xsl:when>
      <xsl:when test="normalize-space(substring($s, 1, 1)) = ''">
        <xsl:call-template name="left-trim">
          <xsl:with-param name="s" select="substring($s, 2)" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$s" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="right-trim">
    <xsl:param name="s" />
    <xsl:choose>
      <xsl:when test="substring($s, 1, 1) = ''">
        <xsl:value-of select="$s"/>
      </xsl:when>
      <xsl:when test="normalize-space(substring($s, string-length($s))) = ''">
        <xsl:call-template name="right-trim">
          <xsl:with-param name="s" select="substring($s, 1, string-length($s) - 1)" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$s" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="trim">
    <xsl:param name="s" />
    <xsl:call-template name="right-trim">
      <xsl:with-param name="s">
        <xsl:call-template name="left-trim">
          <xsl:with-param name="s" select="$s" />
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--文字列置換用テンプレート-->
  <xsl:template name="replace">
    <xsl:param name="str"/>
    <xsl:param name="match"/>
    <xsl:param name="replace"/>
    <xsl:choose>
      <xsl:when test="contains($str,$match)">
        <xsl:value-of select="substring-before($str,$match)"/>
        <xsl:value-of select="$replace"/>
        <xsl:call-template name="replace">
          <xsl:with-param name="str" select="substring-after($str,$match)"/>
          <xsl:with-param name="match" select="$match"/>
          <xsl:with-param name="replace" select="$replace"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ListItems">
    <xsl:param name="valueListData"></xsl:param>
    <xsl:param name="valueDefault"></xsl:param>
    <xsl:variable name="valueListMethodSize">
      <xsl:call-template name="ListMethodCount">
        <xsl:with-param name="valueITEMS" select="$valueListData"/>
        <xsl:with-param name="count" select="0"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:attribute name="listSize">
      <xsl:value-of select="$valueListMethodSize"/>
    </xsl:attribute>
    <xsl:variable name="listdata">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="$valueListData" />
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="ItemList">
      <xsl:with-param name="valueITEMS" select="$listdata"/>
      <xsl:with-param name="valueSELECTED" select="substring-before($valueDefault,';')"/>
      <xsl:with-param name="count" select="1"/>
    </xsl:call-template>
  </xsl:template>

  <!--List型拡張フィールドのName/value分割-->
  <xsl:template name="ItemList">
    <xsl:param name="valueITEMS" />
    <xsl:param name="valueSELECTED" />
    <xsl:param name="valueKEY" select="substring-before($valueITEMS,';')" />
    <xsl:param name="valueVALUE" select="substring-before(substring-after($valueITEMS,';'),';')" />
    <xsl:param name="count"/>
    <xsl:if test="substring-after($valueITEMS,';')!=''">
      <ListItem>
        <xsl:attribute name="selected">
          <xsl:choose>
            <xsl:when test="$valueKEY=$valueSELECTED">true</xsl:when>
            <xsl:otherwise>false</xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        <name>
          <xsl:value-of select="$valueKEY" />
        </name>
        <value>
          <xsl:choose>
            <xsl:when test="$valueVALUE!=''">
              <xsl:value-of select="$valueVALUE" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="substring-after($valueITEMS,';')" />
            </xsl:otherwise>
          </xsl:choose>
        </value>
        <key>
          <xsl:value-of select="$count"/>
        </key>
      </ListItem>
      <xsl:call-template name="ItemList">
        <xsl:with-param name="valueITEMS" select="substring-after(substring-after($valueITEMS,';'),';')" />
        <xsl:with-param name="valueSELECTED" select="$valueSELECTED"/>
        <xsl:with-param name="count" select="$count+1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!--List型拡張フィールド内のitem数カウント-->
  <xsl:template name="ListMethodCount">
    <xsl:param name="valueITEMS" />
    <xsl:param name="valueKEY" select="substring-before($valueITEMS,';')" />
    <xsl:param name="valueVALUE" select="substring-before(substring-after($valueITEMS,';'),';')" />
    <xsl:param name="count"/>
    <xsl:if test="substring-after($valueITEMS,';')!=''">
      <xsl:call-template name="ListMethodCount">
        <xsl:with-param name="valueITEMS" select="substring-after(substring-after($valueITEMS,';'),';')" />
        <xsl:with-param name="count" select="$count+1"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$valueITEMS=''">
      <xsl:value-of select="$count"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="ValueKeyCount">
    <xsl:param name="valueITEMS" />
    <xsl:param name="valueDefault" />
    <xsl:param name="count"/>
    <xsl:param name="valueKEY" select="substring-before($valueITEMS,';')" />
    <xsl:param name="valueDefKEY" select="substring-before($valueDefault,';')" />
    <xsl:param name="valueDefKEYafter" select="substring-after($valueDefault,';')" />
    <xsl:if test="$valueDefKEY!=''">
      <xsl:if test="$valueKEY=$valueDefKEY">
        <xsl:value-of select="$count+1" />
      </xsl:if>
    </xsl:if>
    <xsl:if test="$valueDefKEY='' and $valueDefKEYafter=''">
      <xsl:value-of select="0" />
    </xsl:if>
    <xsl:if test="substring-after($valueITEMS,';')!=''">
      <xsl:call-template name="ValueKeyCount">
        <xsl:with-param name="valueITEMS" select="substring-after(substring-after($valueITEMS,';'),';')" />
        <xsl:with-param name="valueDefault" select="$valueDefault" />
        <xsl:with-param name="count" select="$count+1"/>        
      </xsl:call-template>      
    </xsl:if>    
  </xsl:template>

  <!-- FileFormat -->
  <xsl:template name="FileFormat">
    <xsl:param name="valueFileFormat"/>
    <xsl:variable name="temp">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="$valueFileFormat"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$temp=1">TIFFMulti</xsl:when>
      <xsl:when test="$temp=2">TIFFSingle</xsl:when>
      <xsl:when test="$temp=3">PDFMulti</xsl:when>
      <xsl:when test="$temp=4">JPEG</xsl:when>
      <xsl:when test="$temp=6">PDFSingle</xsl:when>
      <xsl:when test="$temp=7">SlimPDFMulti</xsl:when>
      <xsl:when test="$temp=8">SlimPDFSingle</xsl:when>
      <xsl:when test="$temp=9">XPSMulti</xsl:when>
      <xsl:when test="$temp=10">XPSSingle</xsl:when>
      <xsl:otherwise>PDFMulti</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- SecurePDF -->
  <xsl:template name="SecurePDF">
    <xsl:variable name="valueEncryptionLevel">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="ENCRYPTMODE"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="valueDocumentOpenPassword">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="MASTERPASSWD"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="valueEncryptAutho">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="ENCRYPTAUTHO"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$valueEncryptionLevel=''"></xsl:when>
      <xsl:otherwise>
        <SecurePDF>
          <Enabled>true</Enabled>
          <EncryptionLevel>
            <xsl:choose>
              <xsl:when test="$valueEncryptionLevel=1">40bitRC4</xsl:when>
              <xsl:when test="$valueEncryptionLevel=2">128bitRC4</xsl:when>
              <xsl:when test="$valueEncryptionLevel=4">128bitAES</xsl:when>
              <xsl:otherwise>40bitRC4</xsl:otherwise>
            </xsl:choose>
          </EncryptionLevel>
          <EncryptComponent>AllContents</EncryptComponent>
          <DocumentOpenPassword>
            <xsl:value-of select="$valueDocumentOpenPassword"/>
          </DocumentOpenPassword>
          <Permissions>
            <Enabled>
              <xsl:choose>
                <xsl:when test="$valueEncryptAutho!=''">true</xsl:when>
                <xsl:otherwise>false</xsl:otherwise>
              </xsl:choose>
            </Enabled>
            <PermissionsPassword>
              <xsl:call-template name="trim">
                <xsl:with-param name="s" select="USERPASSWD"/>
              </xsl:call-template>
            </PermissionsPassword>
            <PrintAuthority>
              <xsl:choose>
                <xsl:when test="$valueEncryptAutho mod 2 = 1">Enable-HighResolution</xsl:when>
                <xsl:otherwise>Disable</xsl:otherwise>
              </xsl:choose>
            </PrintAuthority>
            <EditAuthority>
              <xsl:choose>
                <xsl:when test="floor($valueEncryptAutho div 2) mod 2 = 1">Enable-All</xsl:when>
                <xsl:otherwise>Disable</xsl:otherwise>
              </xsl:choose>
            </EditAuthority>
            <Accessibility>
              <xsl:choose>
                <xsl:when test="floor($valueEncryptAutho div 8) mod 2 = 1">true</xsl:when>
                <xsl:otherwise>false</xsl:otherwise>
              </xsl:choose>
            </Accessibility>
            <CopyAuthority>
              <xsl:choose>
                <xsl:when test="floor($valueEncryptAutho div 4) mod 2 = 1">true</xsl:when>
                <xsl:otherwise>false</xsl:otherwise>
              </xsl:choose>
            </CopyAuthority>
          </Permissions>
        </SecurePDF>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Numerical/Decimal value -->
  <xsl:template name="minmaxconv">
    <xsl:param name="valueMinMax"/>
    <xsl:variable name="value">
      <xsl:call-template name="trim">
        <xsl:with-param name="s" select="$valueMinMax"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$value!=''">
        <xsl:value-of select="($value div 1000000)"/>
      </xsl:when>
      <xsl:otherwise/>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
